==> koshoten.net-2.1.2.tar.gz: koshoten-net/admin/includes/languages/japanese/index.php <==
<?php
/*
  $Id: index.php,v 1.1.1.1 2005/06/30 05:04:08 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

define('BOX_CONNECTION_PROTECTED', '³ %s secure SSL connection ݸƤޤ.');
define('BOX_CONNECTION_UNPROTECTED', '³ secure SSL connection ˤ<font color="#ff0000">ݸޤ</font>.');
define('BOX_CONNECTION_UNKNOWN', '³');

define('HEADING_TITLE', '˥塼');
define('HEADING_TITLE01', '');
define('HEADING_TITLE02', 'ʴ');
define('HEADING_TITLE03', '');
define('HEADING_TITLE04', 'Ϣ۸');
define('HEADING_TITLE05', 'ȥǥʴܡ');
define('HEADING_TITLE05_DESCRIPTION', 'ȥǥΥ١ʬʿ礤쥤ˤѹ򤹤ˤϡCSSȥܥɬפޤ<br>ܤϡ<a href="http://www.koshoten.net/" target="_blank" class="knMain"></a>');
define('HEADING_TITLE06', 'ȥǥʾܺ١');

define('TEXT_WELCOME_KOSHOTEN_NET', '<p><b>Koshoten.net2ˤ褦</b></p><p>Koshoten.net2ϡ˸ŽŹ򥤥󥿡ͥåȤǱĤ˸ե꡼Υץ󥽡եȥǤ<br>Koshoten.net2ϥ󥿡ͥåȤǸŽΤԤʡޤޤʵǽܤƤꡢ˥桼ˤɤäƤޤ</p><p>Koshoten.net2ѼԤǤΤȤǤѤɬפޤ<br>ʤˤޤ顢<a href="http://www.koshoten.net/" target="_blank" class="knMainBig"></a>Ѥ</p>');
define('TEXT_KN_MENU_TAX_RATES_DESCRIPTION', 'ǹɽ򤹤ϡΨʿ̵͡ˤꤷƤ');
define('TEXT_KN_MENU_CURRENCIES', '̲');
define('TEXT_KN_MENU_CURRENCIES_LINK', '̲̤...');
define('TEXT_KN_MENU_CURRENCIES_DESCRIPTION', 'åפǼ갷̲ߤꤷޤ');
define('TEXT_KN_MENU_LANGUAGES', '');
define('TEXT_KN_MENU_LANGUAGES_LINK', '̤...');
define('TEXT_KN_MENU_LANGUAGES_DESCRIPTION', 'åפбƤꤷޤ');
define('TEXT_KN_MENU_BACKUP', 'ǡ١Хåå');
define('TEXT_KN_MENU_BACKUP_LINK', 'ǡ١Хååײ̤...');
define('TEXT_KN_MENU_BACKUP_DESCRIPTION', 'ǡ١MySQLˤΥǡХååפޤ');
define('TEXT_KN_MENU_USERS', '桼');
define('TEXT_KN_MENU_USERS_LINK', '桼̤...');
define('TEXT_KN_MENU_USERS_DESCRIPTION', 'å״ԥȤδ򤷤ޤ');
define('TEXT_KN_MENU_USERS_LOGINLOG', '');
define('TEXT_KN_MENU_USERS_LOGINLOG_LINK', '̤...');
define('TEXT_KN_MENU_USERS_LOGINLOG_DESCRIPTION', '̤˥󤷤ϿǧǤޤ');
define('TEXT_KN_MENU_SERVER_INFO', 'о');
define('TEXT_KN_MENU_SERVER_INFO_LINK', 'о̤...');
define('TEXT_KN_MENU_SERVER_INFO_DESCRIPTION', 'Koshoten.net2ưĶɽޤ');
define('TEXT_KN_MENU_BANNER_MANAGER', 'Хʡ');
define('TEXT_KN_MENU_BANNER_MANAGER_LINK', 'Хʡ̤...');
define('TEXT_KN_MENU_BANNER_MANAGER_DESCRIPTION', 'Хʡɽ򤷤ޤ');
define('TEXT_KN_MENU_WHOS_ONLINE', '饤桼');
define('TEXT_KN_MENU_WHOS_ONLINE_LINK', '饤桼̤...');
define('TEXT_KN_MENU_WHOS_ONLINE_DESCRIPTION', 'ߥåפ򸫤Ƥ뤪ͤ狼ޤ');
define('TEXT_KN_MENU_KN_CONFIGURATION', 'ɥХ󥹥');
define('TEXT_KN_MENU_KN_CONFIGURATION_LINK', 'ɥХ󥹥̤...');
define('TEXT_KN_MENU_KN_CONFIGURATION_DESCRIPTION', '˥塼̤ˤʤ䡢С2.1.0δ̤򤷤Ѥޤ');

define('TEXT_KN_MENU_CATEGORIES_EDIT', 'ƥ꡼');
define('TEXT_KN_MENU_CATEGORIES_EDIT_LINK', 'ƥ꡼̤...');
define('TEXT_KN_MENU_CATEGORIES_EDIT_DESCRIPTION', 'ʤϿ˥ƥ꡼ϿƤƥ꡼ˤϲĤޤ');
define('TEXT_KN_MENU_PRODUCTS_EDIT', 'ʴ');
define('TEXT_KN_MENU_PRODUCTS_EDIT_LINK', 'ʴ̤...');
define('TEXT_KN_MENU_PRODUCTS_EDIT_DESCRIPTION', 'ľʤϿꡢʥǡ򸡺뤳ȤǤޤ');
define('TEXT_KN_MENU_PRODUCTS_UPLOADER', 'ʰ');
define('TEXT_KN_MENU_PRODUCTS_UPLOADER_LINK', 'ʰ̤...');
define('TEXT_KN_MENU_PRODUCTS_UPLOADER_DESCRIPTION', 'ʥǡΰ祢åץɤɡǤޤ');
define('TEXT_KN_MENU_SPECIALS', 'òʴ');
define('TEXT_KN_MENU_SPECIALS_LINK', 'òʴ̤...');
define('TEXT_KN_MENU_SPECIALS_DESCRIPTION', '̲ʤꤷʤǤޤ̲ʤϾʴ餬Ǥ');
define('TEXT_KN_MENU_REVIEWS', 'ɾ');
define('TEXT_KN_MENU_REVIEWS_LINK', 'ɾ̤...');
define('TEXT_KN_MENU_REVIEWS_DESCRIPTION', 'ɾǤޤɾϿϾʴ餬Ǥ');
define('TEXT_KN_MENU_PRODUCTS_ATTRIBUTES', 'ʥץϿ');
define('TEXT_KN_MENU_PRODUCTS_ATTRIBUTES_LINK', 'ʥץϿ̤...');
define('TEXT_KN_MENU_PRODUCTS_ATTRIBUTES_DESCRIPTION', 'פˤʤ˰㤤ʤɤ˻ѤޤŽǤɬפʤ⡣');
define('TEXT_KN_MENU_MANUFACTURERS', 'ɲʬܴ');
define('TEXT_KN_MENU_MANUFACTURERS_LINK', 'ɲʬܴ̤...');
define('TEXT_KN_MENU_MANUFACTURERS_DESCRIPTION', 'ƥ꡼Ȥ̤ʬ򤹤뤿ιܤǤʬ̾ϼͳѹǤޤ');

define('TEXT_KN_MENU_ORDERS', 'ʸ');
define('TEXT_KN_MENU_ORDERS_LINK', 'ʸ̤...');
define('TEXT_KN_MENU_ORDERS_DESCRIPTION', 'ʸƤǧ߸ˤ̵ͭ᡼뤳ȤǤޤ');
define('TEXT_KN_MENU_SHIPPING_MODULES', '');
define('TEXT_KN_MENU_SHIPPING_MODULES_LINK', '̤...');
define('TEXT_KN_MENU_SHIPPING_MODULES_DESCRIPTION', 'ʰǤμ̤ѤʤϡͤǤˡ򤢤餫ꤷƤɬפޤ');
define('TEXT_KN_MENU_PAYMENT_MODULES', 'ʧ');
define('TEXT_KN_MENU_PAYMENT_MODULES_LINK', 'ʧ̤...');
define('TEXT_KN_MENU_PAYMENT_MODULES_DESCRIPTION', 'ʰǤμ̤ѤʤϡͤǤʧˡ򤢤餫ꤷƤɬפޤ');
define('TEXT_KN_MENU_ORDER_TOTAL_MODULES', '׹');
define('TEXT_KN_MENU_ORDER_TOTAL_MODULES_LINK', '׹̤...');
define('TEXT_KN_MENU_ORDER_TOTAL_MODULES_DESCRIPTION', 'ͰλѡԻѤꤷޤ۰ʾȯ̵ˤϡ׹ԤܤǹԤޤ');
define('TEXT_KN_MENU_ORDERS_STATUS', 'ʸơ');
define('TEXT_KN_MENU_ORDERS_STATUS_LINK', 'ʸơ̤...');
define('TEXT_KN_MENU_ORDERS_STATUS_DESCRIPTION', 'ؽԤʸơŹˤ碌ꤷޤ');
define('TEXT_KN_MENU_SHIPPING_ESTIMATE', '/ѥå');
define('TEXT_KN_MENU_SHIPPING_ESTIMATE_LINK', '/ѥå̤...');
define('TEXT_KN_MENU_SHIPPING_ESTIMATE_DESCRIPTION', '餫ƾʤ˽̤ꤷ׻ˡѥåν򤹤뤳ȤǤޤ');
define('TEXT_KN_MENU_CUSTOMERS', 'ܵҴ');
define('TEXT_KN_MENU_CUSTOMERS_LINK', 'ܵҴ̤...');
define('TEXT_KN_MENU_CUSTOMERS_DESCRIPTION', 'ߥϿƤ뤪ͤޤ');
define('TEXT_KN_MENU_MAIL_INFO', '᡼ʸ̴');
define('TEXT_KN_MENU_MAIL_INFO_LINK', '᡼ʸ̴̤...');
define('TEXT_KN_MENU_MAIL_INFO_DESCRIPTION', 'μưۿ᡼ͤˤƤ᡼ʸ̤ѹ뤳ȤǤޤ');
define('TEXT_KN_MENU_DIRECT_MAIL', '쥯ȥ᡼');
define('TEXT_KN_MENU_DIRECT_MAIL_LINK', '쥯ȥ᡼̤...');
define('TEXT_KN_MENU_DIRECT_MAIL_DESCRIPTION', 'Τͤ˥᡼ޤ');
define('TEXT_KN_MENU_NEWSLETTERS', '᡼ޥ');
define('TEXT_KN_MENU_NEWSLETTERS_LINK', '᡼ޥ̤...');
define('TEXT_KN_MENU_NEWSLETTERS_DESCRIPTION', 'ͤ˥᡼ޥޤ');
define('TEXT_KN_MENU_ACCOUNT_ITEMS', 'ɽ');
define('TEXT_KN_MENU_ACCOUNT_ITEMS_LINK', 'ɽ̤...');
define('TEXT_KN_MENU_ACCOUNT_ITEMS_DESCRIPTION', 'ͤϿ˵ܤλ/ԻѤꤷޤ');

define('TEXT_KN_MENU_MAKEWAM', 'GETAǡ١');
define('TEXT_KN_MENU_MAKEWAM_LINK', 'GETAǡ١̤...');
define('TEXT_KN_MENU_MAKEWAM_DESCRIPTION', 'Ϣ۸Ǥ褦˥ǡ򹹿ޤƥ꡼侦ʥǡ򹹿ݤɬ¹ԤƤ');
define('TEXT_KN_MENU_GETA_THEMES', 'GETAơ');
define('TEXT_KN_MENU_GETA_THEMES_LINK', 'GETAơ̤...');
define('TEXT_KN_MENU_GETA_THEMES_DESCRIPTION', 'Ϣ۸ѤʣУѤΥڡ뤳ȤǤޤơ̾ѹǽǤ');

define('TEXT_KN_MENU_HEADER_IMAGE01', 'إå');
define('TEXT_KN_MENU_HEADER_IMAGE01_DESCRIPTION', 'å׾κ¦ˤѹ뤳ȤǤޤ<br>gifեΤѲǽǤ<br><small> jpgեѤˤʤϡ/catalog/includes/local/configure.php/admin/includes/local/configure.phpˤKN_HEADER_IMAGE01Υե̾.jpgѹɬפޤ</small>');
define('TEXT_KN_MENU_HEADER_IMAGE02', 'إå');
define('TEXT_KN_MENU_HEADER_IMAGE02_DESCRIPTION', 'å׾α¦ˤѹ뤳ȤǤޤ<br>gifեΤѲǽǤ<br><small> jpgեѤˤʤϡ/catalog/includes/local/configure.php/admin/includes/local/configure.phpˤKN_HEADER_IMAGE02Υե̾.jpgѹɬפޤ</small>');
define('TEXT_KN_MENU_COLUMN_LAYOUT', '쥤');
define('TEXT_KN_MENU_COLUMN_LAYOUT_LINK', '쥤Ȳ̤...');
define('TEXT_KN_MENU_COLUMN_LAYOUT_DESCRIPTION', 'ξܥåɽɽǤޤ');
define('TEXT_KN_MENU_SHOP_INFO', 'Τ餻ʸ̴');
define('TEXT_KN_MENU_SHOP_INFO_LINK', 'Τ餻ʸ̴̤...');
define('TEXT_KN_MENU_SHOP_INFO_DESCRIPTION', 'ե᡼γƥڡ䡢ʸսʬԽ뤳ȤǤޤ');
define('TEXT_KN_MENU_PRODUCTS_LISTING', 'ʰɽ');
define('TEXT_KN_MENU_PRODUCTS_LISTING_LINK', 'ʰɽ̤...');
define('TEXT_KN_MENU_PRODUCTS_LISTING_DESCRIPTION', 'ʰɽܤꤷޤ֤Ǥޤ');
define('TEXT_KN_MENU_IMAGE_SIZE', '');
define('TEXT_KN_MENU_IMAGE_SIZE_LINK', '̤...');
define('TEXT_KN_MENU_IMAGE_SIZE_DESCRIPTION', 'ʲ䥫ƥ꡼ΥѹǤޤ');

define('TEXT_LANGUAGES', '졧');
define('TEXT_KN_BUTTON_UPDATE', '');

define('TEXT_OSC_NOTE', '<b>osCommerceȤϡ</b><br>osCommerceϡkoshoten.netδפȤʤäƤ<a href="http://www.opensource.jp/osd/osd-japanese.html" target="_blank" class="knMain">ץ󥽡</a>ECȹۥƥǤ<br>ʤosCommerceꥸʥγƼﵡǽϺ˥塼򤷤Ƥ');
define('TEXT_KN_NOTE', '<b>koshoten.netȤϡ</b><br>koshoten.netϡosCommerceŽŹ˲¤ƥǤ<br>ŪosCommerce˵ǽɲäΤʤΤǡץ󥽡ȤƼͳѡѤǽǤ');
define('TEXT_GETA_NOTE', '<b>GETAȤϡ</b><br>Ϣ۷׻󥸥ʣǣţԣˡפϢ۸¸륷ƥǡȶ(IPA)»ܤŪ󵻽Ѱȡפθ̤Ǥ<br>ѤˤӳƼ諒եȥΥ󥹥ȡ뤪꤬ɬפǤ<br>ܤ<a href="http://geta.ex.nii.ac.jp/" target="_blank" class="knMain"></a><br><img src="http://geta.ex.nii.ac.jp/img/geta_1.gif">');
?>

==> koshoten.net-2.1.3.tar.gz: koshoten-net/admin/includes/languages/japanese/index.php <==
<?php
/*
  $Id: index.php,v 1.2 2005/09/22 01:00:27 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

define('BOX_CONNECTION_PROTECTED', '³ %s secure SSL connection ݸƤޤ.');
define('BOX_CONNECTION_UNPROTECTED', '³ secure SSL connection ˤ<font color="#ff0000">ݸޤ</font>.');
define('BOX_CONNECTION_UNKNOWN', '³');

define('HEADING_TITLE', '˥塼');
define('HEADING_TITLE01', '');
define('HEADING_TITLE02', 'ʴ');
define('HEADING_TITLE03', '');
define('HEADING_TITLE04', 'Ϣ۸');
define('HEADING_TITLE05', 'ȥǥʴܡ');
define('HEADING_TITLE05_DESCRIPTION', 'ȥǥΥ١ʬʿ礤쥤ˤѹ򤹤ˤϡCSSȥܥɬפޤ<br>ܤϡ<a href="http://www.koshoten.net/" target="_blank" class="knMain"></a>');
define('HEADING_TITLE06', 'ȥǥʾܺ١');
define('TEXT_SIMPLE_MENU', 'ܥ˥塼');

define('TEXT_WELCOME_KOSHOTEN_NET', '<p><b>Koshoten.net2ˤ褦</b></p><p>Koshoten.net2ϡ˸ŽŹ򥤥󥿡ͥåȤǱĤ˸ե꡼Υץ󥽡եȥǤ<br>Koshoten.net2ϥ󥿡ͥåȤǸŽΤԤʡޤޤʵǽܤƤꡢ<br>˥桼ˤɤäƤޤ</p><p>Koshoten.net2ϥץ󥽡եȥǤѼԤǤΤȤǤѤɬפޤ<br>ʤˤޤ顢<a href="http://www.koshoten.net/" target="_blank"></a>Ѥ</p>');
define('TEXT_KN_MENU_TAX_RATES_DESCRIPTION', 'ǹɽ򤹤ϡΨʿ̵͡ˤꤷƤ');
define('TEXT_KN_MENU_CURRENCIES', '̲');
define('TEXT_KN_MENU_CURRENCIES_LINK', '̲̤...');
define('TEXT_KN_MENU_CURRENCIES_DESCRIPTION', 'åפǼ갷̲ߤꤷޤ');
define('TEXT_KN_MENU_LANGUAGES', '');
define('TEXT_KN_MENU_LANGUAGES_LINK', '̤...');
define('TEXT_KN_MENU_LANGUAGES_DESCRIPTION', 'åפбƤꤷޤ');
define('TEXT_KN_MENU_BACKUP', 'ǡ١Хåå');
define('TEXT_KN_MENU_BACKUP_LINK', 'ǡ١Хååײ̤...');
define('TEXT_KN_MENU_BACKUP_DESCRIPTION', 'ǡ١MySQLˤΥǡХååפޤ');
define('TEXT_KN_MENU_USERS', '桼');
define('TEXT_KN_MENU_USERS_LINK', '桼̤...');
define('TEXT_KN_MENU_USERS_DESCRIPTION', 'å״ԥȤδ򤷤ޤ');
define('TEXT_KN_MENU_USERS_LOGINLOG', '');
define('TEXT_KN_MENU_USERS_LOGINLOG_LINK', '̤...');
define('TEXT_KN_MENU_USERS_LOGINLOG_DESCRIPTION', '̤˥󤷤ϿǧǤޤ');
define('TEXT_KN_MENU_SERVER_INFO', 'о');
define('TEXT_KN_MENU_SERVER_INFO_LINK', 'о̤...');
define('TEXT_KN_MENU_SERVER_INFO_DESCRIPTION', 'Koshoten.net2ưĶɽޤ');
define('TEXT_KN_MENU_BANNER_MANAGER', 'Хʡ');
define('TEXT_KN_MENU_BANNER_MANAGER_LINK', 'Хʡ̤...');
define('TEXT_KN_MENU_BANNER_MANAGER_DESCRIPTION', 'Хʡɽ򤷤ޤ');
define('TEXT_KN_MENU_WHOS_ONLINE', '饤桼');
define('TEXT_KN_MENU_WHOS_ONLINE_LINK', '饤桼̤...');
define('TEXT_KN_MENU_WHOS_ONLINE_DESCRIPTION', 'ߥåפ򸫤Ƥ뤪ͤ狼ޤ');
define('TEXT_KN_MENU_KN_CONFIGURATION', 'ɥХ󥹥');
define('TEXT_KN_MENU_KN_CONFIGURATION_LINK', 'ɥХ󥹥̤...');
define('TEXT_KN_MENU_KN_CONFIGURATION_DESCRIPTION', '˥塼̤ˤʤ䡢С2.1.0δ̤򤷤Ѥޤ');

define('TEXT_KN_MENU_CATEGORIES_EDIT', 'ƥ꡼');
define('TEXT_KN_MENU_CATEGORIES_EDIT_LINK', 'ƥ꡼̤...');
define('TEXT_KN_MENU_CATEGORIES_EDIT_DESCRIPTION', 'ʤϿ˥ƥ꡼ϿƤƥ꡼ˤϲĤޤ');
define('TEXT_KN_MENU_PRODUCTS_EDIT', 'ʴ');
define('TEXT_KN_MENU_PRODUCTS_EDIT_LINK', 'ʴ̤...');
define('TEXT_KN_MENU_PRODUCTS_EDIT_DESCRIPTION', 'ľʤϿꡢʥǡ򸡺뤳ȤǤޤ');
define('TEXT_KN_MENU_PRODUCTS_UPLOADER', 'ʰ');
define('TEXT_KN_MENU_PRODUCTS_UPLOADER_LINK', 'ʰ̤...');
define('TEXT_KN_MENU_PRODUCTS_UPLOADER_DESCRIPTION', 'ʥǡΰ祢åץɤɡǤޤ');
define('TEXT_KN_MENU_SPECIALS', 'òʴ');
define('TEXT_KN_MENU_SPECIALS_LINK', 'òʴ̤...');
define('TEXT_KN_MENU_SPECIALS_DESCRIPTION', '̲ʤꤷʤǤޤ̲ʤϾʴ餬Ǥ');
define('TEXT_KN_MENU_REVIEWS', 'ɾ');
define('TEXT_KN_MENU_REVIEWS_LINK', 'ɾ̤...');
define('TEXT_KN_MENU_REVIEWS_DESCRIPTION', 'ɾǤޤɾϿϾʴ餬Ǥ');
define('TEXT_KN_MENU_PRODUCTS_ATTRIBUTES', 'ʥץϿ');
define('TEXT_KN_MENU_PRODUCTS_ATTRIBUTES_LINK', 'ʥץϿ̤...');
define('TEXT_KN_MENU_PRODUCTS_ATTRIBUTES_DESCRIPTION', 'פˤʤ˰㤤ʤɤ˻ѤޤŽǤɬפʤ⡣');
define('TEXT_KN_MENU_MANUFACTURERS', 'ɲʬܴ');
define('TEXT_KN_MENU_MANUFACTURERS_LINK', 'ɲʬܴ̤...');
define('TEXT_KN_MENU_MANUFACTURERS_DESCRIPTION', 'ƥ꡼Ȥ̤ʬ򤹤뤿ιܤǤʬ̾ϼͳѹǤޤ');

define('TEXT_KN_MENU_ORDERS', 'ʸ');
define('TEXT_KN_MENU_ORDERS_LINK', 'ʸ̤...');
define('TEXT_KN_MENU_ORDERS_DESCRIPTION', 'ʸƤǧ߸ˤ̵ͭ᡼뤳ȤǤޤ');
define('TEXT_KN_MENU_SHIPPING_MODULES', '');
define('TEXT_KN_MENU_SHIPPING_MODULES_LINK', '̤...');
define('TEXT_KN_MENU_SHIPPING_MODULES_DESCRIPTION', 'ʰǤμ̤ѤʤϡͤǤˡ򤢤餫ꤷƤɬפޤ');
define('TEXT_KN_MENU_PAYMENT_MODULES', 'ʧ');
define('TEXT_KN_MENU_PAYMENT_MODULES_LINK', 'ʧ̤...');
define('TEXT_KN_MENU_PAYMENT_MODULES_DESCRIPTION', 'ʰǤμ̤ѤʤϡͤǤʧˡ򤢤餫ꤷƤɬפޤ');
define('TEXT_KN_MENU_ORDER_TOTAL_MODULES', '׹');
define('TEXT_KN_MENU_ORDER_TOTAL_MODULES_LINK', '׹̤...');
define('TEXT_KN_MENU_ORDER_TOTAL_MODULES_DESCRIPTION', 'ͰλѡԻѤꤷޤ۰ʾȯ̵ˤϡ׹ԤܤǹԤޤ');
define('TEXT_KN_MENU_ORDERS_STATUS', 'ʸơ');
define('TEXT_KN_MENU_ORDERS_STATUS_LINK', 'ʸơ̤...');
define('TEXT_KN_MENU_ORDERS_STATUS_DESCRIPTION', 'ؽԤʸơŹˤ碌ꤷޤ');
define('TEXT_KN_MENU_SHIPPING_ESTIMATE', '/ѥå');
define('TEXT_KN_MENU_SHIPPING_ESTIMATE_LINK', '/ѥå̤...');
define('TEXT_KN_MENU_SHIPPING_ESTIMATE_DESCRIPTION', '餫ƾʤ˽̤ꤷ׻ˡѥåν򤹤뤳ȤǤޤ');
define('TEXT_KN_MENU_CUSTOMERS', 'ܵҴ');
define('TEXT_KN_MENU_CUSTOMERS_LINK', 'ܵҴ̤...');
define('TEXT_KN_MENU_CUSTOMERS_DESCRIPTION', 'ߥϿƤ뤪ͤޤ');
define('TEXT_KN_MENU_MAIL_INFO', '᡼ʸ̴');
define('TEXT_KN_MENU_MAIL_INFO_LINK', '᡼ʸ̴̤...');
define('TEXT_KN_MENU_MAIL_INFO_DESCRIPTION', 'μưۿ᡼ͤˤƤ᡼ʸ̤ѹ뤳ȤǤޤ');
define('TEXT_KN_MENU_DIRECT_MAIL', '쥯ȥ᡼');
define('TEXT_KN_MENU_DIRECT_MAIL_LINK', '쥯ȥ᡼̤...');
define('TEXT_KN_MENU_DIRECT_MAIL_DESCRIPTION', 'Τͤ˥᡼ޤ');
define('TEXT_KN_MENU_NEWSLETTERS', '᡼ޥ');
define('TEXT_KN_MENU_NEWSLETTERS_LINK', '᡼ޥ̤...');
define('TEXT_KN_MENU_NEWSLETTERS_DESCRIPTION', 'ͤ˥᡼ޥޤ');
define('TEXT_KN_MENU_ACCOUNT_ITEMS', 'ɽ');
define('TEXT_KN_MENU_ACCOUNT_ITEMS_LINK', 'ɽ̤...');
define('TEXT_KN_MENU_ACCOUNT_ITEMS_DESCRIPTION', 'ͤϿ˵ܤλ/ԻѤꤷޤ');

define('TEXT_KN_MENU_MAKEWAM', 'GETAǡ١');
define('TEXT_KN_MENU_MAKEWAM_LINK', 'GETAǡ١̤...');
define('TEXT_KN_MENU_MAKEWAM_DESCRIPTION', 'Ϣ۸Ǥ褦˥ǡ򹹿ޤƥ꡼侦ʥǡ򹹿ݤɬ¹ԤƤ');
define('TEXT_KN_MENU_GETA_THEMES', 'GETAơ');
define('TEXT_KN_MENU_GETA_THEMES_LINK', 'GETAơ̤...');
define('TEXT_KN_MENU_GETA_THEMES_DESCRIPTION', 'Ϣ۸ѤʣУѤΥڡ뤳ȤǤޤơ̾ѹǽǤ');

define('TEXT_KN_MENU_HEADER_IMAGE01', 'إå');
define('TEXT_KN_MENU_HEADER_IMAGE01_DESCRIPTION', 'å׾κ¦ˤѹ뤳ȤǤޤ<br>gifեΤѲǽǤ<br><small> jpgեѤˤʤϡ/catalog/includes/local/configure.php/admin/includes/local/configure.phpˤKN_HEADER_IMAGE01Υե̾.jpgѹɬפޤ</small>');
define('TEXT_KN_MENU_HEADER_IMAGE02', 'إå');
define('TEXT_KN_MENU_HEADER_IMAGE02_DESCRIPTION', 'å׾α¦ˤѹ뤳ȤǤޤ<br>gifեΤѲǽǤ<br><small> jpgեѤˤʤϡ/catalog/includes/local/configure.php/admin/includes/local/configure.phpˤKN_HEADER_IMAGE02Υե̾.jpgѹɬפޤ</small>');
define('TEXT_KN_MENU_COLUMN_LAYOUT', '쥤');
define('TEXT_KN_MENU_COLUMN_LAYOUT_LINK', '쥤Ȳ̤...');
define('TEXT_KN_MENU_COLUMN_LAYOUT_DESCRIPTION', 'ξܥåɽɽǤޤ');
define('TEXT_KN_MENU_SHOP_INFO', 'Τ餻ʸ̴');
define('TEXT_KN_MENU_SHOP_INFO_LINK', 'Τ餻ʸ̴̤...');
define('TEXT_KN_MENU_SHOP_INFO_DESCRIPTION', 'ե᡼γƥڡ䡢ʸսʬԽ뤳ȤǤޤ');
define('TEXT_KN_MENU_PRODUCTS_LISTING', 'ʰɽ');
define('TEXT_KN_MENU_PRODUCTS_LISTING_LINK', 'ʰɽ̤...');
define('TEXT_KN_MENU_PRODUCTS_LISTING_DESCRIPTION', 'ʰɽܤꤷޤ֤Ǥޤ');
define('TEXT_KN_MENU_IMAGE_SIZE', '');
define('TEXT_KN_MENU_IMAGE_SIZE_LINK', '̤...');
define('TEXT_KN_MENU_IMAGE_SIZE_DESCRIPTION', 'ʲ䥫ƥ꡼ΥѹǤޤ');

define('TEXT_LANGUAGES', '졧');
define('TEXT_KN_BUTTON_UPDATE', '');

define('TEXT_OSC_NOTE', '<b>osCommerceȤϡ</b><br>osCommerceϡkoshoten.netδפȤʤäƤ<a href="http://www.opensource.jp/osd/osd-japanese.html" target="_blank" class="knMain">ץ󥽡</a>ECȹۥƥǤ<br>ʤosCommerceꥸʥγƼﵡǽϺ˥塼򤷤Ƥ');
define('TEXT_KN_NOTE', '<b>koshoten.netȤϡ</b><br>koshoten.netϡosCommerceŽŹ˲¤ƥǤ<br>ŪosCommerce˵ǽɲäΤʤΤǡץ󥽡ȤƼͳѡѤǽǤ');
define('TEXT_GETA_NOTE', '<b>GETAȤϡ</b><br>Ϣ۷׻󥸥ʣǣţԣˡפϢ۸¸륷ƥǡȶ(IPA)»ܤŪ󵻽Ѱȡפθ̤Ǥ<br>ѤˤӳƼ諒եȥΥ󥹥ȡ뤪꤬ɬפǤ<br>ܤ<a href="http://geta.ex.nii.ac.jp/" target="_blank" class="knMain"></a><br><img src="http://geta.ex.nii.ac.jp/img/geta_1.gif">');
?>
